# "fix" underlinking:
%define _disable_ld_no_undefined 1

%global srcname parmap

Name:           ocaml-%{srcname}
Version:        1.2.5
Release:        %mkrel 1
Summary:        OCaml library for exploiting multicore architectures

Group:          Development/OCaml
# The usual OCaml linking exception applies
License:        LGPLv2+ with exceptions
URL:            https://rdicosmo.github.io/parmap/
Source0:        https://github.com/rdicosmo/parmap/releases/download/%{version}/%{srcname}-%{version}.tar.gz

BuildRequires:  ocaml >= 4.03
BuildRequires:  ocaml-dune-devel
BuildRequires:  ocaml-graphics-devel
BuildRequires:  ocaml-odoc
BuildRequires:  ocaml-result-devel

%description
Parmap is a minimalistic library for exploiting multicore architectures
in OCaml programs with minimal modifications: if you want to use your
many cores to accelerate an operation which happens to be a map, fold or
map/fold (map-reduce), just use Parmap's parmap, parfold and parmapfold
primitives in place of the standard List.map and friends, and specify
the number of subprocesses to use with the optional parameter ~ncores.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and signature
files for developing applications that use %{name}.

%prep
%autosetup -n %{srcname}-%{version} -p0

# Some tests exhaust memory on the 32-bit builders; scale them down
# See https://github.com/rdicosmo/parmap/issues/92
%if 0%{?__isa_bits} == 32
sed -i 's/10000000/1000000/' tests/{float,simple}scale.ml
%endif

%build
dune build %{?_smp_mflags} --profile release
dune build @doc

# Relink the stublibs with $RPM_LD_FLAGS.
cd _build/default/src
ocamlmklib -g -ldopt '%{build_ldflags}' -o parmap_stubs \
  $(ar t libparmap_stubs.a)
cd -

%install
dune install --destdir=%{buildroot}

# We do not want the dune markers
find _build/default/_doc/_html -name .dune-keep -delete

# We do not want the ml files
find %{buildroot}%{_libdir}/ocaml -name \*.ml -delete

# We install the documentation with the doc macro
rm -fr %{buildroot}%{_prefix}/doc

%check
#dune runtest --profile release

%files
%doc AUTHORS CHANGES README.md
%license LICENSE
%dir %{_libdir}/ocaml/parmap
%{_libdir}/ocaml/parmap/META
%{_libdir}/ocaml/parmap/*.cma
%{_libdir}/ocaml/parmap/*.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/parmap/*.cmxs
%endif
%{_libdir}/ocaml/stublibs/dllparmap_stubs.so

%files devel
%doc _build/default/_doc/*
%{_libdir}/ocaml/parmap/dune-package
%{_libdir}/ocaml/parmap/opam
%{_libdir}/ocaml/parmap/*.a
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/parmap/*.cmxa
%{_libdir}/ocaml/parmap/*.cmx
%endif
%{_libdir}/ocaml/parmap/*.cmt
%{_libdir}/ocaml/parmap/*.cmti
%{_libdir}/ocaml/parmap/*.mli



%changelog
* Fri Nov 22 2024 daviddavid <daviddavid> 1.2.5-1.mga10
+ Revision: 2118596
- new version: 1.2.5

* Sat May 21 2022 pterjan <pterjan> 1.2.3-2.mga9
+ Revision: 1859624
- Rebuild for OCaml 4.14

* Fri Oct 15 2021 tv <tv> 1.2.3-1.mga9
+ Revision: 1751660
- imported package ocaml-parmap


* Tue Oct 05 2021 Richard W.M. Jones <rjones@redhat.com> - 1.2.3-3
- OCaml 4.13.1 build

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Mon May  3 2021 Jerry James <loganjerry@gmail.com> - 1.2.3-1
- Version 1.2.3

* Wed Apr 28 2021 Jerry James <loganjerry@gmail.com> - 1.2.1-1
- Version 1.2.1
- Drop upstreamed -float-array patch

* Fri Apr 16 2021 Jerry James <loganjerry@gmail.com> - 1.2-1
- Initial package
